@@ -1,6 +1,6 @@
 import click
 import git
-from init.commands import init
+from gitutor.init.commands import init
 
 
 @click.group()
@@ -26,4 +26,4 @@ def main():
     cli(obj={})
 
 if __name__ == '__main__':
-    cli(obj={})
\ No newline at end of file
+    cli(obj={})
